# -*- coding: utf-8 -*-
"""
oathldap -- Python package for OATH-LDAP client tool
"""

import sys
import getpass

import ldap0
import ldap0.base
from ldap0 import LDAPError
from ldap0.ldapobject import ReconnectLDAPObject

__all__ = [
    'cli_output',
    'ABORT_MSG',
    'ErrorExit',
    'SEP_LINE',
]

#---------------------------------------------------------------------------
# Constants
#---------------------------------------------------------------------------

SEP_LINE = 80 * '-'

ABORT_MSG = 'Aborted -> exit'


#---------------------------------------------------------------------------
# Classes
#---------------------------------------------------------------------------

class ErrorExit(Exception):
    """
    to be raised if any condition should result in program exit
    """

    def __init__(self, msg, code=1):
        Exception.__init__(self, msg)
        self.code = code

#---------------------------------------------------------------------------
# Functions
#---------------------------------------------------------------------------

def cli_output(text, lf_before=1, lf_after=1):
    """
    Command-line program output
    """
    sys.stdout.write(''.join((
        lf_before*'\n',
        text,
        lf_after*'\n',
    )))


def interactive_ldapconnect(ldap_uri, ldap_who):
    """
    returns LDAPObject connected as token specified by :serial: after
    interactively asking the user for the two enrollment password parts
    """
    while True:
        cli_output('You have to login as admin.')
        ldap_pw = getpass.getpass('Enter password for %r' % ldap_who)
        if not ldap_pw:
            raise ErrorExit(ABORT_MSG)
        try:
            oath_ldap = ReconnectLDAPObject(ldap_uri)
            oath_ldap.simple_bind_s(ldap_who, ldap_pw)
        except ldap0.INVALID_CREDENTIALS:
            cli_output('Password(s) wrong => try again')
        else:
            break
    return oath_ldap # end of interactive_ldapconnect()
